#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <glib/gi18n.h>

#include "bookmarks-lens.h"
#include "shared-values.h"

static void bookmarks_lens_class_init (BookmarksLensClass *klass);
static void bookmarks_lens_init       (BookmarksLens *self);
static void bookmarks_lens_dispose    (GObject *object);
static void bookmarks_lens_finalize   (GObject *object);

G_DEFINE_TYPE (BookmarksLens, bookmarks_lens, G_TYPE_OBJECT);

static void
bookmarks_lens_class_init (BookmarksLensClass *klass)
{
	GObjectClass *object_class = G_OBJECT_CLASS (klass);

	object_class->dispose = bookmarks_lens_dispose;
	object_class->finalize = bookmarks_lens_finalize;

	return;
}

static void
bookmarks_lens_init (BookmarksLens *self)
{
	self->lens = NULL;
	self->scope = NULL;


	self->lens = unity_lens_new(LENS_PATH, "bookmarks");
	g_object_set(G_OBJECT(self->lens),
	             "search-hint", "Website Title",
	             "visible", TRUE,
	             "search-in-global", TRUE,
	             NULL);

	GList * categories = NULL;

	GIcon * icon = g_icon_new_for_string("bookmarks-lens-panel", NULL);
	UnityCategory * cat = unity_category_new(_("Bookmarks"), icon, UNITY_CATEGORY_RENDERER_VERTICAL_TILE);
	categories = g_list_append(categories, cat);

	unity_lens_set_categories(self->lens, categories);

	self->scope = bookmarks_scope_new();

	unity_lens_add_local_scope(self->lens, self->scope->scope);
	unity_lens_export(self->lens, NULL);

	return;
}

static void
bookmarks_lens_dispose (GObject *object)
{
	BookmarksLens * self = BOOKMARKS_LENS(object);

	if (self->lens != NULL) {
		g_object_unref(self->lens);
		self->lens = NULL;
	}

	if (self->scope != NULL) {
		g_object_unref(self->scope);
		self->scope = NULL;
	}

	G_OBJECT_CLASS (bookmarks_lens_parent_class)->dispose (object);
	return;
}

static void
bookmarks_lens_finalize (GObject *object)
{

	G_OBJECT_CLASS (bookmarks_lens_parent_class)->finalize (object);
	return;
}

BookmarksLens *
bookmarks_lens_new (void)
{
	return BOOKMARKS_LENS(g_object_new(BOOKMARKS_LENS_TYPE, NULL));
}
